==> docx4j-openxml-objects-sml-8.3.1-sources.jar: org/xlsx4j/sml/CTRevisions.java <==
/*
 *  Copyright 2010-2013, Plutext Pty Ltd.
 *   
 *  This file is part of xlsx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.xlsx4j.sml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_Revisions complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_Revisions">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice maxOccurs="unbounded">
 *         &lt;element name="rrc" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionRowColumn" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rm" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionMove" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rcv" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionCustomView" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rsnm" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionSheetRename" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="ris" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionInsertSheet" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rcc" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionCellChange" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rfmt" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionFormatting" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="raf" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionAutoFormatting" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rdn" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionDefinedName" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rcmt" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionComment" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rqt" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionQueryTableField" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rcft" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionConflict" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/choice>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_Revisions", propOrder = {
    "rrcOrRmOrRcv"
})
public class CTRevisions implements Child
{

    @XmlElements({
        @XmlElement(name = "rrc", type = CTRevisionRowColumn.class),
        @XmlElement(name = "rm", type = CTRevisionMove.class),
        @XmlElement(name = "rcv", type = CTRevisionCustomView.class),
        @XmlElement(name = "rsnm", type = CTRevisionSheetRename.class),
        @XmlElement(name = "ris", type = CTRevisionInsertSheet.class),
        @XmlElement(name = "rcc", type = CTRevisionCellChange.class),
        @XmlElement(name = "rfmt", type = CTRevisionFormatting.class),
        @XmlElement(name = "raf", type = CTRevisionAutoFormatting.class),
        @XmlElement(name = "rdn", type = CTRevisionDefinedName.class),
        @XmlElement(name = "rcmt", type = CTRevisionComment.class),
        @XmlElement(name = "rqt", type = CTRevisionQueryTableField.class),
        @XmlElement(name = "rcft", type = CTRevisionConflict.class)
    })
    protected List<Object> rrcOrRmOrRcv;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the rrcOrRmOrRcv property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the rrcOrRmOrRcv property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getRrcOrRmOrRcv().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTRevisionRowColumn }
     * {@link CTRevisionMove }
     * {@link CTRevisionCustomView }
     * {@link CTRevisionSheetRename }
     * {@link CTRevisionInsertSheet }
     * {@link CTRevisionCellChange }
     * {@link CTRevisionFormatting }
     * {@link CTRevisionAutoFormatting }
     * {@link CTRevisionDefinedName }
     * {@link CTRevisionComment }
     * {@link CTRevisionQueryTableField }
     * {@link CTRevisionConflict }
     * 
     * 
     */
    public List<Object> getRrcOrRmOrRcv() {
        if (rrcOrRmOrRcv == null) {
            rrcOrRmOrRcv = new ArrayList<Object>();
        }
        return this.rrcOrRmOrRcv;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-sml-11.5.1-sources.jar: org/xlsx4j/sml/CTRevisions.java <==
/*
 *  Copyright 2010-2013, Plutext Pty Ltd.
 *   
 *  This file is part of xlsx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.xlsx4j.sml;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.Unmarshaller;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlElements;
import jakarta.xml.bind.annotation.XmlTransient;
import jakarta.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_Revisions complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_Revisions">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice maxOccurs="unbounded">
 *         &lt;element name="rrc" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionRowColumn" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rm" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionMove" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rcv" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionCustomView" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rsnm" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionSheetRename" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="ris" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionInsertSheet" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rcc" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionCellChange" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rfmt" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionFormatting" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="raf" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionAutoFormatting" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rdn" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionDefinedName" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rcmt" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionComment" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rqt" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionQueryTableField" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="rcft" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_RevisionConflict" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/choice>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_Revisions", propOrder = {
    "rrcOrRmOrRcv"
})
public class CTRevisions implements Child
{

    @XmlElements({
        @XmlElement(name = "rrc", type = CTRevisionRowColumn.class),
        @XmlElement(name = "rm", type = CTRevisionMove.class),
        @XmlElement(name = "rcv", type = CTRevisionCustomView.class),
        @XmlElement(name = "rsnm", type = CTRevisionSheetRename.class),
        @XmlElement(name = "ris", type = CTRevisionInsertSheet.class),
        @XmlElement(name = "rcc", type = CTRevisionCellChange.class),
        @XmlElement(name = "rfmt", type = CTRevisionFormatting.class),
        @XmlElement(name = "raf", type = CTRevisionAutoFormatting.class),
        @XmlElement(name = "rdn", type = CTRevisionDefinedName.class),
        @XmlElement(name = "rcmt", type = CTRevisionComment.class),
        @XmlElement(name = "rqt", type = CTRevisionQueryTableField.class),
        @XmlElement(name = "rcft", type = CTRevisionConflict.class)
    })
    protected List<Object> rrcOrRmOrRcv;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the rrcOrRmOrRcv property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the rrcOrRmOrRcv property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getRrcOrRmOrRcv().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTRevisionRowColumn }
     * {@link CTRevisionMove }
     * {@link CTRevisionCustomView }
     * {@link CTRevisionSheetRename }
     * {@link CTRevisionInsertSheet }
     * {@link CTRevisionCellChange }
     * {@link CTRevisionFormatting }
     * {@link CTRevisionAutoFormatting }
     * {@link CTRevisionDefinedName }
     * {@link CTRevisionComment }
     * {@link CTRevisionQueryTableField }
     * {@link CTRevisionConflict }
     * 
     * 
     */
    public List<Object> getRrcOrRmOrRcv() {
        if (rrcOrRmOrRcv == null) {
            rrcOrRmOrRcv = new ArrayList<Object>();
        }
        return this.rrcOrRmOrRcv;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
